#
# spec file for package supportutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define support_libdir /usr/lib/supportconfig
# ensure usr-merge does not effect existing SLE
%if %suse_version < 1550
%define _sbindir /sbin
%endif

Name:           supportutils
Version:        3.2.9
Release:        2.2
Summary:        Support Troubleshooting Tools
License:        GPL-2.0-only
Group:          System/Monitoring
Url:            https://github.com/openSUSE/supportutils
Source:         %{name}-%{version}.tar.gz
Requires:       iproute2
Requires:       ncurses-utils
%ifarch ppc64le s390x
Requires:       numactl
%endif
Requires:       tar
Requires:       /usr/bin/which
Requires:       /usr/bin/sed
Requires:       /usr/bin/awk
Provides:       supportconfig-plugin-rc
BuildArch:      noarch

%description
A package containing troubleshooting tools. This package contains
the following: supportconfig, chkbin, getappcore, analyzevmcore

%prep
%setup -q

%build
gzip -9f man/*3
gzip -9f man/*5
gzip -9f man/*8

%install
pwd;ls -la
mkdir -p %{buildroot}%{_sbindir}
install -d %{buildroot}%{_sysconfdir}/supportutils
install -d %{buildroot}%{_mandir}/man3
install -d %{buildroot}%{_mandir}/man5
install -d %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{support_libdir}/resources
install -d %{buildroot}%{support_libdir}/plugins
install -d %{buildroot}%{_docdir}/%{name}
install -m 544 bin/supportconfig %{buildroot}%{_sbindir}
install -m 544 bin/chkbin %{buildroot}%{_sbindir}
install -m 544 bin/getappcore %{buildroot}%{_sbindir}
install -m 544 bin/analyzevmcore %{buildroot}%{_sbindir}
install -m 444 bin/supportconfig.rc %{buildroot}%{support_libdir}/resources
install -m 644 man/*.3.gz %{buildroot}%{_mandir}/man3
install -m 644 man/*.5.gz %{buildroot}%{_mandir}/man5
install -m 644 man/*.8.gz %{buildroot}%{_mandir}/man8
install -m 644 man/COPYING.GPLv2 %{buildroot}%{_docdir}/%{name}

%files
%defattr(-,root,root)
%{_sbindir}/supportconfig
%{_sbindir}/chkbin
%{_sbindir}/getappcore
%{_sbindir}/analyzevmcore
%dir %{support_libdir}
%dir %{support_libdir}/resources
%dir %{support_libdir}/plugins
%dir %{_docdir}/%{name}
%dir %{_sysconfdir}/supportutils

%if 0%{?suse_version} < 1500
%doc %{_docdir}/%{name}/COPYING.GPLv2
%else
%license %{_docdir}/%{name}/COPYING.GPLv2
%endif

%{support_libdir}/resources/*
%doc %{_mandir}/man5/*
%doc %{_mandir}/man3/*
%doc %{_mandir}/man8/*

%changelog
* Tue Dec  3 2024 jason.record@suse.com
- Changes to version 3.2.9
  + Map running PIDs to RPM package owner aiding BPF program detection (bsc#1222896, bsc#1213291, PED-8221)
  + Supportconfig available in current distro (PED-7131)
  + Corrected display issues (bsc#1231396)
  + NFS takes too long, showmount times out (bsc#1231423)
  + Merged sle15 and master branches (bsc#1233726, PED-11669)
* Thu Aug  1 2024 jesse.chandler@suse.com
- Changes to version 3.2.8
  + Avoid getting duplicate kernel verifications in boot.text (pr#190)
  + lvm: suppress file descriptor leak warnings from lvm commands (pr#191)
  + docker_info: Add timestamps to container logs (pr#196)
  + Key value pairs and container log timestamps (bsc#1222021 PED-8211, pr#198)
  + Update supportconfig get pam.d sorted (pr#199)
  + yast_files: Exclude .zcat (pr#201)
  + Sanitize grub bootloader (bsc#1227127, pr#203)
  + Sanitize regcodes (pr#204)
  + Improve product detection (pr#205)
  + Add read_values for s390x (bsc#1228265, pr#206)
  + hardware_info: Remove old alsa ver check (pr#209)
  + drbd_info: Fix incorrect escape of quotes (pr#210)
* Mon Apr 15 2024 jason.record@suse.com
- Changes in version 3.1.30
  + Added -V key:value pair option (bsc#1222021, PED-8211)
  + Avoid getting duplicate kernel verifications in boot.text (pr#193)
  + Suppress file descriptor leak warnings from lvm commands (pr#192, bsc#1220082)
  + Includes container log timestamps (pr#197)
* Wed Feb 14 2024 jason.record@suse.com
- Changes to version 3.2.7
  + Extended scaling for performance (bsc#1214713)
  + Corrected get_sles_ver for SLE Micro (bsc#1219241)
  + Check nvidida-persistenced state (bsc#1219639)
* Mon Feb 12 2024 jason.record@suse.com
- Changes to version 3.1.29
  + Extended scaling for performance (bsc#1214713)
  + Fixed kdumptool output error (bsc#1218632)
  + Corrected podman ID errors (bsc#1218812)
  + Duplicate non root podman entries removed (bsc#1218814)
  + Corrected get_sles_ver for SLE Micro (bsc#1219241)
  + Check nvidida-persistenced state (bsc#1219639)
* Fri Jan 19 2024 jason.record@suse.com
- Changes to version 3.2.6
  + Corrected podman .ID error (bsc#1218812)
  + Remove duplicate non-root podman users (bsc#1218814)
* Thu Jan 11 2024 jason.record@suse.com
- Changes to version 3.2.5
  + Fixed smart disk error (bsc#1218282)
  + Fixed ipvsadm logic error (bsc#1218324)
  + Correctly detects Xen Dom0 (bsc#1218201)
* Thu Jan 11 2024 jason.record@suse.com
- Additional changes in version 3.1.28
  + ipset - List entries for all sets
  + ipvsadm - Inspect the virtual server table (pr#185)
  + Correctly detects Xen Dom0 (bsc#1218201)
  + Fixed smart disk error (bsc#1218282)
* Wed Dec 20 2023 jason.record@suse.com
- Changes in version 3.1.28
  + Inhibit the conversion of port numbers to port names for network files (cherry picked from commit 55f5f716638fb15e3eb1315443949ed98723d250)
  + powerpc: collect rtas_errd.log and lp_diag.log files (pr#175)
  + Get list of pam.d file (cherry picked from commit eaf35c77fd4bc039fd7e3d779ec1c2c6521283e2)
  + Remove supportutils requires for util-linux-systemd and kmod (bsc#1193173)
  + Added missing klp information to kernel-livepatch.txt (bsc#1216390)
  + Fixed plugins creating empty files when using supportconfig.rc (bsc#1216388)
  + Provides long listing for /etc/sssd/sssd.conf (bsc#1211547)
  + Optimize lsof usage (bsc#1183663)
  + Added mokutil commands for secureboot (pr#179)
  + Collects chrony or ntp as needed (bsc#1196293)
* Mon Dec 18 2023 jason.record@suse.com
- Changes in version 3.2.4
  + Inhibit the conversion of port numbers to port names for network files (pr#177)
  + powerpc: collect rtas_errd.log and lp_diag.log files (pr#174)
  + Get list of pam.d file (pr#176)
  + Remove supportutils requires for util-linux-systemd and kmod (bsc#1193173)
  + Provides long listing for /etc/sssd/sssd.conf (bsc#1211547)
  + Optimize lsof usage (bsc#1183663)
  + Added mokutil commands for secureboot (pr#178)
  + ipset - List entries for all sets (pr#180)
  + ipvsadm - Inspect the virtual server table (pr#181)
* Fri Nov 17 2023 jason.record@suse.com
- Changes in version 3.1.27
  + Fixed podman display issue (bsc#1217287)
  + Added nvme-stas configuration to nvme.txt (bsc#1216049)
  + Added timed command to fs-files.txt (bsc#1216827)
  + Collects zypp history file issue#166 (bsc#1216522)
  + Changed -x OPTION to really be exclude only (issue#146)
  + Collect HA related rpm package versions in ha.txt (pr#169)
* Fri Nov 17 2023 jason.record@suse.com
- Changes in versin 3.2.3
  + Fixed podman display issue (bsc#1217287)
  + Added timed command to fs-files.txt (bsc#1216827)
  + Added nvme-stas configuration to nvme.txt (bsc#1216049)
  + Collects zypp history file issue#166 pr#170 (bsc#1216522)
  + Collect HA related rpm package versions in ha.txt (pr#168)
  + Change -x OPTION to really be exclude only issue#146 (pr#161)
* Wed Oct 18 2023 jason.record@suse.com
- Changes in version 3.2.2
  + Added supportutils to current PED-4456
  + Fixed kernel and added user live patching PED-4524
  + Fixed plugins creating empty files bsc#1216388
  + Fixed supportconfig using external test command bsc#1216150
  + Removed older versions of SLES_VER bsc#1216147
  + Fixed supportconfig kdump and analyzevmcore errors bsc#1216146
  + Cron and At are replaced with systemd.timer bsc#1216229
  + Offers apparmor or selinux based on configuration bsc#1216233
  + Filted proc access errors bsc#1216151
  + Remove all SuSE-release references bsc#1216228
  + Remove references to /etc/init.d bsc#1216230
  + Changed config directory to /etc/supportutuils for all conf and header.txt bsc#1216232
  + Removed package requires for kmod and util-linux-systemd
  + Remove check_service function from supportconfig.rc bsc#1216231
  + Support has been removed for scplugin.rc, use supportconfig.rc bsc#1216241
* Fri Sep  1 2023 jason.record@suse.com
- Changes in version 3.1.26
  + powerpc plugin to collect the slots and active memory (bsc#1210950)
  + A Cleartext Storage of Sensitive Information vulnerability CVE-2022-45154
  + supportconfig: collect BPF information (pr#154)
  + Added additional iscsi information (pr#155)
* Wed Jul 26 2023 jason.record@suse.com
- Added run time detection (bsc#1213127)
* Mon Jun 26 2023 jason.record@suse.com
- ha_info sle15 uses /var/log/pacemaker/ (pq#153)
* Thu Jun  1 2023 jason.record@suse.com
- Changes for supportutils version 3.1.25
  + Removed iSCSI passwords CVE-2022-45154 (bsc#1207598)
  + powerpc: Collect lsslot,amsstat, and opal elogs (pr#149)
  + powerpc: collect invscout logs (pr#150)
  + powerpc: collect RMC status logs (pr#151)
  + Added missing nvme nbft commands (bsc#1211599)
  + Fixed invalid nvme commands (bsc#1211598)
  + Added missing podman information (PED-1703, bsc#1181477)
  + Removed dependency on sysfstools
  + Check for systool use (bsc#1210015)
  + Added selinux checking (bsc#1209979)
  + Updated SLES_VER matrix
* Mon Mar 20 2023 jason.record@suse.com
- Fixed missing status detail for apparmor (bsc#1196933)
- Corrected invalid argument list in docker.txt (bsc#1206608)
- Applies limit equally to sar data and text files (bsc#1207543)
- Collects hwinfo hardware logs (bsc#1208928)
- Collects lparnumascore logs (issue#148)
* Thu Feb  2 2023 hp.jansen@suse.com
- Add dependency to `numactl` on ppc64le and `s390x`, this enforces
  that `numactl --hardware` data is provided in supportconfigs
* Thu Jan 26 2023 jason.record@suse.com
- Changes to supportconfig.rc version 3.1.11-35
  + Corrected _sanitize_file to include iscsi.conf and others (bsc#1206402)
* Fri Dec  2 2022 jason.record@suse.com
- Changes to supportconfig version 3.1.11-46.4
  + Added plymouth_info
* Thu Nov 17 2022 jason.record@suse.com
- Changes to getappcore version 1.53.02
  + The location of chkbin was updated earlier. This documents that
    change (bsc#1205533, bsc#1204942)
* Fri Nov 11 2022 jason.record@suse.com
- Changes to supportconfig version 3.1.11-46.3
  + Added missed sanitation check on crash.txt (bsc#1203818)
- Changes to supportconfig.rc version 3.1.11-30
  + Added check to _sanitize_file
  + Using variable for replement text in _sanitize_file
* Tue Oct 18 2022 jason.record@suse.com
- Added lifecycle information (issue#140)
* Tue Oct 18 2022 jason.record@suse.com
- Changes to version 3.1.21
  + Added type output with df command in fs-diskio.txt (issue#141)
  + Gather all files in /etc/security/limits.d/ (issue#142)
  + Fixed KVM virtualization detection on bare metal (bsc#1184689)
  + Added logging using journalctl (bsc#1200330)
  + Passwords correctly removed from email.txt, updates.txt and fs-iscsi.txt (bsc#1203818)
  + Added system logging configuration and checking in messages_config.txt (issue#103)
  + If rsyslog not installed collect more from journalctl (issue#120)
  + Added systemd-status.txt for the status of all service units (issue#125)
  + autofs includes files in (+dir:<path>) (issue#111)
  + Get current sar data before collecting files (bsc#1192648)
  + Collects everything in /etc/multipath/ (bsc#1192252)
  + Collects power management information in hardware.txt (bsc#1197428)
  + Checks for suseconnect-ng or SUSEConnect packages (bsc#1202337)
  + Fixed conf_files and conf_text_files so y2log is gathered (issue#134, bsc#1202269)
  + Update to nvme_info and block_info #133 (bsc#1202417)
  + Added IO scheduler (issue#136)
  + Added includedir directories from /etc/sudoers (bsc#1188086)
* Thu Jun  2 2022 Jason Record <jason.record@suse.com>
- Added a listing to /dev/mapper/. #129
* Tue Mar 15 2022 Jason Record <jason.record@suse.com>
- Spec file adjusted for usr-merge
* Fri Mar  4 2022 Jason Record <jason.record@suse.com>
- Changes to version 3.1.20
  + Added command blkid #114
  + Added s390x specific files and output #115
  + Fix for invalid argument during updates (bsc#1193204)
  + Optimized conf_files, conf_files_text and log_cmd functions #118
  + Fixed iscsi initiator name (bsc#1195797)
  + Added rpcinfo -p output #116
  + Included /etc/sssd/conf.d configuration files #100
* Mon Jan 10 2022 Jason Record <jason.record@suse.com>
- Changes to version 3.1.19
  + Made /proc directory and network names spaces configurable (bsc#1193868)
* Wed Dec 15 2021 Jason Record <jason.record@suse.com>
- Changes to version 3.1.19
  + Removed chronyc DNS lookups with -n switch (bsc#1193732)
* Wed Nov 17 2021 Jason Record <jason.record@suse.com>
- Merged Include udev rules in /lib/udev/rules.d/ #113
- Merged Move localmessage/warm logs out of messages.txt to new localwarn.txt #87
* Mon Oct 18 2021 Jason Record <jason.record@suse.com>
- getappcore identifies compressed core files (bsc#1191794)
* Mon Oct  4 2021 Jason Record <jason.record@suse.com>
- Installing to /usr/sbin instead of /sbin (bsc#1191096)
- Added shared memory as a log directory for emergency use (bsc#1190943)
* Wed Sep  8 2021 Jason Record <jason.record@suse.com>
- Fixed cron package for RPM validation (bsc#1190315)
- Updated spec file with correct URL
* Mon Aug 16 2021 Jason Record <jason.record@suse.com>
- Changes to version 3.1.18
  + Added email.txt based on OPTION_EMAIL #108 (bsc#1189028)
  + Include 'multipath -t' output in mpio.txt #105
  + Improved lsblk readability with --ascsi #106
  + Removed duplicate commands in network.txt
  + Remove duplicate firewalld status output #109
* Tue Jul  6 2021 Jason Record <jason.record@suse.com>
- Changes to version 3.1.17
  + Adding ethtool options g l m to network.txt (jsc#SLE-18240)
* Mon Jun  7 2021 Jason Record <jason.record@suse.com>
- Changes to version 3.1.16
  + lsof options to improve performance (bsc#1186687)
* Thu May 27 2021 Jason Record <jason.record@suse.com>
- Fixes to supportconfig
  + Exclude rhn.conf from etc.txt (bsc#1186347)
* Mon May 24 2021 Jason Record <jason.record@suse.com>
- analyzevmcore supports local directories (bsc#1186397)
* Wed May 12 2021 Jason Record <jason.record@suse.com>
- getappcore checks for valid compression binary (bsc#1185991)
- getappcore does not trigger errors with help message (bsc#1185993)
* Mon Apr 19 2021 Jason Record <jason.record@suse.com>
- Additions to version 3.1.15
  + Checks package signatures in rpm.txt (bsc#1021918)
  + Optimize find (bsc#1184912)
- Using zypper --xmlout (bsc#1181351)
- Error fix for sysfs.txt (bsc#1089870)
* Thu Apr 15 2021 Jason Record <jason.record@suse.com>
- Additions to version 3.1.15
  + Added drbd-overview to drbd.txt
  + Added list-timers to systemd.txt (bsc#1169348)
  + Including nfs4 in search (bsc#1184829)
- Minor: Fix a typo (executible -> executable) #99
- Changed minor wording to loaded module
* Mon Mar 22 2021 jason.record@gmail.com
- [powerpc] Collect dynamic_debug log files for ibmvNIC #98 (bsc#1183826)
* Thu Mar 11 2021 jason.record@gmail.com
- Fixed mismatched taint flags (bsc#1178491)
- Removed redundant fdisk code that can cause timeout issues (bsc#1181679)
- Supportconfig processes -f without hanging (bsc#1182904)
* Wed Mar  3 2021 Thorsten Kukuk <kukuk@suse.com>
- Remove net-tools from requires, it does not contain any tool
  anymore used by supportutils pr#96
* Tue Mar  2 2021 Mike Latimer mlatimer@suse.com
- Collect logs for power specific components (using iprconfig) pr#94 (bsc#1182950)
  + Additional nvme information
  + Additional kdump configuration and logs
* Tue Feb 16 2021 jason.record@gmail.com
- Additions to version 3.1.14
  + [powerpc] Collect logs for power specific components (HNV) pr#88 (bsc#1181911)
  + Updated pam.txt documentation explaining GDPR
  + ha.txt: Fix pacemaker.log location for SLE15 pr#90
  + supportconfig: use readlink /proc/<pid>/cwd to get cwd list instead of lsof pr#91
  + supportconfig: sssd_info consistency pr#93
  + Includes NVMe information with OPTION_NVME=1 in nvme.txt (bsc#1176370, SLE-15932)
* Thu Feb  4 2021 jason.record@gmail.com
- No longer truncates boot log (bsc#1181610)
* Tue Jan 19 2021 Thorsten Kukuk <kukuk@suse.com>
- Require the awk, which and sed commands instead of packages to
  allow alternate implementations on embedded/Edge systems
* Thu Dec 31 2020 jason.record@suse.com
- Additions to version 3.1.13
  + Added update-alternatives to etc.txt #82
  + Collects rotated logs with different compression types (bsc#1180478)
  + Added GPL-2.0-only license tag to spec file
* Tue Dec  8 2020 jason.record@suse.com
- Additions to version 3.1.12
  + btrfs_info: add -pce argument to qgroup show #80
  + docker: add /etc/docker/daemon.json contents #81
* Tue Nov 10 2020 jason.record@suse.com
- Additions to version 3.1.12
  + Capture IBM Power bootlist (SLE-15557)
  + Fix spelling typos in man pages #78
  + Collect multipath wwids file #77
  + Removed unnecessary appname parameter from HTTP upload URL
  + added aa-status #74
* Thu Sep  3 2020 jason.record@suse.com
- Additions to version 3.1.12
  + [powerpc] Collect logs for power specific components #72 (bscn#1176895)
  + supportconfig: fs-btrfs: Add "btrfs device stats" output #73
* Wed Jul  1 2020 jason.record@suse.com
- Additions to version 3.1.11
  + Changes affecting supportconfig
  - disk_info: Show discard information in lsblk #70
  - memory_info: Show VMware memory balloon infomation #71
* Mon Apr 27 2020 jason.record@suse.com
- Addition to version 3.1.10
  + Changes affecting analyzevmcore
  - Fixed typo in error message #67
  + Changes affecting supportconfig
  - Fixed btrfs errors (bsc#1168894)
  - Large ntp.txt with binary data (bsc#1169122)
  - Check btrfs balance status #69
* Fri Mar 13 2020 jason.record@suse.com
- Addition to version 3.1.9
  + Changes affecting getappcore
  - Added core file validation (bsc#1166126)
  - Added -j <PID> to extract core from systemd journal
  - Capture coredumptctl info in getappcore.log
  + Changed filename prefixes from nts_ to scc_ (SLE-8702, SLE-6762)
  - The new prefix references SUSE Customer Center
* Tue Mar  3 2020 jason.record@suse.com
- Addition to version 3.1.8
  + Changes affecting getappcore
  - Added -u for HTTPS and -f for FTPES uploads to SUSE FTP servers
  - Replaced Novell with SUSE FTP servers (bsc#1165475)
  - Uses /etc/getappcore.conf if present
  + Changes affecting supportconfig
  - Added missed Power collection per bsc#1162539
  - Added zypper patterns output to updates.txt #66
* Mon Mar  2 2020 jason.record@suse.com
- Addition to version 3.1.7
  + exclude /proc/pagetypeinfo as it can be an expensive operation on some systems (bsc#1162357)
  + Readded LPM/DLPAR data for Power (bsc#1162539)
* Thu Nov 21 2019 jason.record@suse.com
- Addition to version 3.1.6
  + Strip trailing commas from process names #64 (bsc#1156837)
  + Dynamically select compression method (bsc#1145233)
  + Updated detailed unit information fix in systemd.txt (bsc#1023308)
  + Fixed supportconig.conf man page with order placement
  + Include IPv6 routes (bsc#1089877)
* Fri Oct 18 2019 jason.record@suse.com
- Updated to version 3.1.5
  + Removed root .snapshots directory from full file list (bsc#1154482)
* Wed Oct 16 2019 jason.record@suse.com
- Updated to version 3.1.4
  + Removed LPM/DLPAR data for POWER (bsc#1111029)
  + prevent running 'systool -vb memory' by default on systems with 16TB or more #57 (bsc#1127734)
  + Tumbleweed support #50
  + Added zypper orphaned packages check to updates.txt
  + Cpuset listing #52
  + Docker disunite #53
  + Added sed and gawk to spec requirements (bsc#1137336)
  + Added nstat to network
  + Add collection of livepatch information #63
  + Check for missing ldap.conf file
* Thu May  9 2019 jason.record@suse.com
- Updated to version 3.1.3
  + Uses SUSE FTP servers (bsc#1132865)
  + btrfs quota #43
  + supportconfig: open-files: add file flags #44
  + Merged etc_info: Add support for .cfg files in /etc dir #46
  + Silence warning in rpm backup db collection path #47
  + Set files in tarball to 660 instead of 600 #48
  + SUSE separation finalized (bsc#1125623)
  + Default compression through xz, but -z forces bzip2
  + Updated man pages (bsc#1088234)
  + Changed VAR_OPTION_BIN_TIMEOUT_SEC from 300 to 120
  + Avoids some IO delays (bsc#1100529)
  + Corrected supported services help info for -U
  + Collects iSCSI Target information (bsc#1133844)
  + FTPES uses --ssl-reqd instead of depricated --ftp-ssl
  + Defaults to https FTP server uploads (bsc#1134599)
* Mon Mar  4 2019 jason.record@suse.com
- Updated to version 3.1.2
  + Fixed missing sapconf and log (bsc#1081326)
  + Added timed_log_cmd to hwinfo and showmount commands (bsc#1120967)
* Fri Mar  1 2019 jason.record@suse.com
- Updated to version 3.1.1
  + Fixed X missing /prob/fb error (bsc#1127069)
  + Fixed dasdview -f (bsc#1109664)
  + Clarified -t help description (bsc#1121043)
  + Fixed grep error in NTP when /etc/cron.d is empty (bsc#1127063)
  + Collects systemd journal with minimum install (bsc#1094225)
  + Supportconfig fails on bzip archives (bsc#1120049)
  + Get few drbd output & configuration #42
* Mon Feb 18 2019 jason.record@suse.com
- Corrected missed SUSE separation lines
- Fixed invalid exit code commands (bsc#1125666)
- CVE-2018-19640: supportutils: Users can kill arbitrary processes
  (CVE-2018-19640 bsc#1118463)
- User can overwrite arbitrary log files in support tar
  (CVE-2018-19638 bsc#1118460)
- Code execution if run with -v
  (CVE-2018-19639 bsc#1118462)
- Static temporary filename allows overwriting of files
  (CVE-2018-19637 bsc#1117776)
* Fri Feb 15 2019 jason.record@suse.com
- Included additional SUSE separation (bsc#1125609)
- Merged added listing of locked packes by zypper #41
* Wed Jan 30 2019 jason.record@suse.com
- Corrected spec file errors
* Mon Jan 28 2019 jason.record@suse.com
- Added firewall-cmd info
- btrfs filesystem usage
- Add ls -lA --time-style=long-iso /etc/products.d/
- Dump lsof errors
- Added corosync status to ha_info
* Fri Dec 28 2018 jason.record@suse.com
- Clarified -x functionality in supportconfig(8) (bsc#1115245)
- Dump find errors in ib_info
* Fri Oct 26 2018 jason.record@suse.com
- Exclude pam.txt per GDPR by default (bsc#1112461)
* Thu Oct 11 2018 jason.record@suse.com
- udev service and journal content (bsc#1051797)
- supportconfig collects tuned profile settings (bsc#1071545)
- sfdisk -d no disk device specified (bsc#1043311)
* Thu Aug 23 2018 jason.record@suse.com
- Added vulnerabilites check in basic-health.txt (bsc#1105849)
* Thu Jul 12 2018 jason.record@suse.com
- Added backup rpm database directory
- Updated URLs in documentation
* Tue Jul 10 2018 jason.record@suse.com
- Added only sched_domain from cpu0
* Fri Jun 15 2018 jason.record@suse.com
- Blacklist sched_domain from proc.txt (bsc#1046681)
* Mon Mar 26 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Fri Feb  2 2018 jason.record@suse.com
- Accounts for firewalld now (bsc#1079137)
- Added dmesg taint seach
- Removed mii-tool from networking
- Updated HA to use chrony
- Added kdumptool calibrate to crash.txt
- Removed SLES_VER case for sles8,9 and 10
* Thu Feb  1 2018 jason.record@suse.com
- Added tuned feature OPTION_TUNED tuned.txt (bsc#1071545)
- Fixed udev service
- Fixed no disk device with sfdisk (bsc#1078638)
* Tue Jan 30 2018 jason.record@suse.com
- Removed OPTION_SAM from man pages and resource file
- Validated missing commands
- Updated apparmor with systemctl service
- Replaced deprecated networking commands (bsc#1078318)
* Mon Jan 29 2018 jason.record@suse.com
- Removed sam_info since suse_sam is no longer available
- Assigned SLE15 to SLES_VER selections (bsc#1078168)
* Mon Jan 29 2018 jason.record@suse.com
- Includes X without display issue (bsc#1077813)
- Fixes for Infiniband (bsc#1071294)
- Using chrony for NTP (bsc#1077818)
* Fri Jan 26 2018 jason.record@suse.com
- Added os-release processing (bsc#1077758)
- Removed invalid string tty string (bsc#1077681)
- Added SLE15 taint values (bsc#1077683)
* Tue Jan 23 2018 jason.record@suse.com
- Added transactional update with OPTION_TRANSACTIONAL=1
- Updated supportconfig.conf.5 with OPTION_TRANSACTIONAL
* Fri Jan 19 2018 jason.record@suse.com
- Fixed docker package detection (bsc#1069457)
* Fri Jan  5 2018 jason.record@suse.com
- Replaced route with ip route (bsc#1070379)
- Added systemd-delta to systemd.txt (bsc#1071924)
- Changed repos -u to repos -d (bsc#1071926)
- Added rdma-core for infiniband (bsc#1071294)
* Tue Dec 19 2017 jason.record@suse.com
- Branding updates fate#324067
- Fixed piped spelling error
* Fri Oct 27 2017 jason.record@suse.com
- Separated core supportconfig function into resources/supportconfig.rc
- Removed virtualization functions
- Removed OES functions
- Removed eDirectory functions
* Thu Oct 26 2017 jason.record@suse.com
- Initial commit
